@@ -50,7 +50,7 @@ def render_page(app, protocol, cdn):
     footer = teams_config().get('footer', True)
 
     return _index_page_tpl.generate(title=meta.title, description=meta.description, protocol=protocol,
-                                    script=True, content='', base_url=base_url,
+                                    script=True, content='', base_url=base_url, version=version,
                                     js_file=meta.js_file or [], js_code=meta.js_code, css_style=meta.css_style,
                                     css_file=meta.css_file or [], theme=theme, footer=footer)
 
